@@ -1,4 +1,6 @@
 from .robot import Robot
+from signal import SIGTERM, SIGINT, SIGHUP, signal
+import sys
 
 conf = {
     "communication": {
@@ -6,6 +8,9 @@ conf = {
     }
 }
 
+def interrupt_handler(signum, frame):
+    Server.stop()
+    sys.exit()
 
 class Server():
     _is_server_started = False
@@ -18,6 +23,10 @@ class Server():
             print('Server already started')
             return
 
+        signal(SIGTERM, interrupt_handler)
+        signal(SIGINT, interrupt_handler)
+        signal(SIGHUP, interrupt_handler)
+
         Server._robot = Robot(conf)
         Server._is_server_started = True
         Server._robot.print_manual()
@@ -32,12 +41,12 @@ class Server():
 
         comm_mngr.stop()
 
-        Server._robot.get_thread().join(1)
+        Server._robot.get_thread().join()
 
         Server._is_server_started = False
         Server._robot = None
 
-        print('Server stopped')
+        print('Server terminated')
 
     @staticmethod
     def get_robot():
